@@ -177,11 +177,7 @@ void KMixWindow::initActions()
 	//actionCollection()->addAction(QStringLiteral( a->objectName()), a );
 	KStandardAction::preferences(this, SLOT(showSettings()), actionCollection());
 	KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
-	QAction* action = actionCollection()->addAction(QStringLiteral("launch_kdesoundsetup"));
-	action->setText(i18n("Audio Setup..."));
-	connect(action, SIGNAL(triggered(bool)), SLOT(slotKdeAudioSetupExec()));
-
-	action = actionCollection()->addAction(QStringLiteral("hide_kmixwindow"));
+	QAction* action = actionCollection()->addAction(QStringLiteral("hide_kmixwindow"));
 	action->setText(i18n("Hide Mixer Window"));
 	connect(action, SIGNAL(triggered(bool)), SLOT(hideOrClose()));
 	actionCollection()->setDefaultShortcut(action, Qt::Key_Escape);
@@ -492,11 +488,15 @@ void KMixWindow::loadBaseConfig()
 	KConfigGroup config(KSharedConfig::openConfig(), "Global");
 
 	GlobalConfigData& gcd = GlobalConfig::instance().data;
-
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
 	QList<QString> preferredMixersInSoundMenu;
 	preferredMixersInSoundMenu = config.readEntry("Soundmenu.Mixers", preferredMixersInSoundMenu);
 	GlobalConfig::instance().setMixersForSoundmenu(preferredMixersInSoundMenu.toSet());
-
+#else
+	const QStringList preferredMixers = config.readEntry("Soundmenu.Mixers", QStringList());
+	const QSet<QString> preferredMixersSet(preferredMixers.begin(), preferredMixers.end());
+	GlobalConfig::instance().setMixersForSoundmenu(preferredMixersSet);
+#endif
 	m_startVisible = config.readEntry("Visible", false);
 	m_multiDriverMode = config.readEntry("MultiDriver", false);
 	m_defaultCardOnStart = config.readEntry("DefaultCardOnStart", "");
@@ -523,14 +523,11 @@ void KMixWindow::loadBaseConfig()
 
 	// The following log is very helpful in bug reports. Please keep it.
 	m_backendFilter = config.readEntry<>("Backends", QList<QString>());
-	qCDebug(KMIX_LOG)
-	<< "Backends: " << m_backendFilter;
+	qCDebug(KMIX_LOG) << "Backends: " << m_backendFilter;
 
 	// show/hide menu bar
 	bool showMenubar = config.readEntry("Menubar", true);
-
-	if (_actionShowMenubar)
-		_actionShowMenubar->setChecked(showMenubar);
+	if (_actionShowMenubar!=nullptr) _actionShowMenubar->setChecked(showMenubar);
 }
 
 /**
@@ -952,19 +949,6 @@ void KMixWindow::unplugged(const QString &udi)
 
 }
 
-/**
- * Create a widget with an error message
- * This widget shows an error message like "no mixers detected.
- void KMixWindow::setErrorMixerWidget()
- {
- QString s = i18n("Please plug in your soundcard. No soundcard found. Probably you have not set it up or are missing soundcard drivers. Please check your operating system manual for installing your soundcard."); // !! better text
- m_errorLabel = new QLabel( s,this  );
- m_errorLabel->setAlignment( Qt::AlignCenter );
- m_errorLabel->setWordWrap(true);
- m_errorLabel->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
- m_wsMixers->addTab( m_errorLabel, i18n("No soundcard found") );
- }
- */
 
 /**
  *
@@ -1222,11 +1206,6 @@ void KMixWindow::toggleMenuBar()
 	menuBar()->setVisible(_actionShowMenubar->isChecked());
 }
 
-void KMixWindow::slotKdeAudioSetupExec()
-{
-    forkExec(QStringList() << "kcmshell5" << "kcm_phonon");
-}
-
 void KMixWindow::forkExec(const QStringList& args)
 {
 	int pid = KProcess::startDetached(args);
@@ -1255,12 +1234,12 @@ void KMixWindow::slotSelectMasterClose(QObject*)
 
 void KMixWindow::slotSelectMaster()
 {
-	Mixer *mixer = Mixer::getGlobalMasterMixer();
-	if (mixer != 0)
+	const Mixer *mixer = Mixer::getGlobalMasterMixer();
+	if (mixer!=nullptr)
 	{
 		if (!m_dsm)
 		{
-			m_dsm = new DialogSelectMaster(Mixer::getGlobalMasterMixer(), this);
+			m_dsm = new DialogSelectMaster(mixer, this);
 			connect(m_dsm, SIGNAL(destroyed(QObject*)), this, SLOT(slotSelectMasterClose(QObject*)));
 			m_dsm->setAttribute(Qt::WA_DeleteOnClose, true);
 			m_dsm->show();
@@ -1270,7 +1249,7 @@ void KMixWindow::slotSelectMaster()
 	}
 	else
 	{
-		KMessageBox::error(0, i18n("No sound card is installed or currently plugged in."));
+		KMessageBox::error(nullptr, KMixToolBox::noDevicesWarningString());
 	}
 }
 
@@ -1297,4 +1276,3 @@ void KMixWindow::newMixerShown(int /*tabIndex*/)
 			action->setVisible(!view->isDynamic());
 	}
 }
-
