@@ -622,7 +622,7 @@ static QWidget *createLabel(QWidget *parent, const QString &label, Qt::Orientati
 
 
 void MDWSlider::addSliders( QBoxLayout *volLayout, char type, Volume& vol,
-                            QList<QAbstractSlider *>& ref_sliders, QString tooltipText)
+                            QList<QAbstractSlider *>& ref_sliders, const QString &tooltipText)
 {
 	const int minSliderSize = fontMetrics().height() * 10;
 	long minvol = vol.minVolume();
@@ -1132,7 +1132,7 @@ void MDWSlider::showContextMenu(const QPoint &pos)
 		// Mixer_PULSE::moveStream() does not record the stream ID in the
 		// output stream list and hence cannot get its PulseAudio stream index.
 		// I don't know whether this is a design decision or a PA limitation.
-		if (mixDevice()->id().endsWith(":event")) m_moveMenu->setEnabled(false);
+		if (mixDevice()->id().endsWith(QLatin1String(":event"))) m_moveMenu->setEnabled(false);
 
 		menu->addMenu( m_moveMenu );
 	}
